@@ -73,12 +73,6 @@ HOME_ENVIRONMENT_VARIABLE = EnvironmentVariable(
     'COLCON_HOME',
     'Set the configuration directory (default: ~/.colcon)')
 
-"""Environment variable to set the log directory"""
-LOG_PATH_ENVIRONMENT_VARIABLE = EnvironmentVariable(
-    'COLCON_LOG_PATH',
-    'Set the log directory (default: $COLCON_HOME/log, to disable: '
-    '{os.devnull})'.format_map(locals()))
-
 
 def main(*, command_name='colcon', argv=None):
     """
@@ -101,9 +95,16 @@ def main(*, command_name='colcon', argv=None):
     :param list argv: The list of arguments
     :returns: The return code
     """
+    try:
+        return _main(command_name=command_name, argv=argv)
+    except KeyboardInterrupt:
+        return signal.SIGINT
+
+
+def _main(*, command_name, argv):
     global colcon_logger
     # default log level
-    colcon_logger.setLevel(logging.WARN)
+    colcon_logger.setLevel(logging.WARNING)
     set_logger_level_from_env(
         colcon_logger, '{command_name}_LOG_LEVEL'.format_map(locals()).upper())
     colcon_logger.debug(
@@ -264,13 +265,12 @@ def add_log_level_argument(parser):
     """
     parser.add_argument(
         '--log-base',
-        default='log',
-        help='The base path for all log directories (default: log, to '
+        help='The base path for all log directories (default: ./log, to '
              'disable: {os.devnull})'.format_map(globals()))
     parser.add_argument(
         '--log-level', action=LogLevelAction,
         help='Set log level for the console output, either by numeric or '
-             'string value (default: warn)')
+             'string value (default: warning)')
 
 
 class LogLevelAction(argparse.Action):
@@ -481,8 +481,6 @@ def verb_main(context, logger):
     try:
         # catch exceptions raised in verb extension
         rc = context.args.main(context=context)
-    except KeyboardInterrupt:
-        rc = signal.SIGINT
     except RuntimeError as e:  # noqa: F841
         # only log the error message for "known" exceptions
         logger.error(
